EZX API
===============
EZX Api Network Client, messages and library functions for sending and receiving orders to the EZX iServer.

Installing
============

.. code-block:: bash

    pip install ezx-pyapi

Usage
=====

.. code-block:: bash

    >>> from src.example import custom_sklearn
    >>> custom_sklearn.get_sklearn_version()
    '0.24.2'